@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"エディターでインレー ヒントを有効にします。",
 		"エディターでインレー ヒントのフォント サイズを制御します。\'0\' に設定すると、`#editor.fontSize#` の 90% が使用されます。",
 		"エディターでインレー ヒントのフォント ファミリを制御します。",
-		"行の高さを制御します。フォント サイズに基づいて行の高さを計算する場合には、0 を使用します。",
+		"行の高さを制御します。\r\n - 0 を使用してフォント サイズから行の高さを自動的に計算します。\r\n - 0 から 8 までの値は、フォント サイズの乗数として使用されます。\r\n - 8 以上の値は有効値として使用されます。",
 		"ミニマップを表示するかどうかを制御します。",
 		"ミニマップのサイズは、エディターのコンテンツと同じです (スクロールする場合があります)。",
 		"ミニマップは、必要に応じて、エディターの高さを埋めるため、拡大または縮小します (スクロールしません)。",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.ja", {
 		"このエディターのルーラーがレンダリングする単一領域の文字数。",
 		"このエディターのルーラーの色です。",
 		"特定の等幅文字数の後に垂直ルーラーを表示します。複数のルーラーには複数の値を使用します。配列が空の場合はルーラーを表示しません。",
+		"垂直スクロールバーは、必要な場合にのみ表示されます。",
+		"垂直スクロールバーは常に表示されます。",
+		"垂直スクロールバーは常に非表示になります。",
+		"垂直スクロールバーの表示を制御します。",
+		"水平スクロールバーは、必要な場合にのみ表示されます。",
+		"水平スクロールバーは常に表示されます。",
+		"水平スクロールバーは常に非表示になります。",
+		"水平スクロールバーの表示を制御します。",
+		"垂直スクロールバーの幅。",
+		"水平スクロールバーの高さ。",
+		"クリックするとページ単位でスクロールするか、クリック位置にジャンプするかを制御します。",
 		"エディターにインライン候補を自動的に表示するかどうかを制御します。",
+		"置換テキストが挿入テキストのプレフィックスである場合にのみインライン候補を表示します。",
+		"置換テキストが挿入テキストのサブワードである場合にのみインライン候補をレンダリングします。",
+		"インライン候補をレンダリングするために使用するモードを制御します。",
 		"カーソルの右のテキストを上書きせずに候補を挿入します。",
 		"候補を挿入し、カーソルの右のテキストを上書きします。",
 		"入力候補を受け入れるときに単語を上書きするかどうかを制御します。これは、この機能の利用を選択する拡張機能に依存することにご注意ください。",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.ja", {
 		"提案のアイコンを表示するか、非表示にするかを制御します。",
 		"候補ウィジェットの下部にあるステータス バーの表示を制御します。",
 		"提案の結果をエディターでプレビューするかどうかを制御します。",
+		"置換テキストが挿入テキストのプレフィックスである場合にのみプレビューを表示します。",
+		"置換テキストが挿入テキストのサブワードである場合にのみプレビューを表示します。",
+		"候補のプレビューをレンダリングするために使用するモードを制御します。",
 		"候補の詳細をラベル付きのインラインで表示するか、詳細ウィジェットにのみ表示するかを制御します",
 		"この設定は非推奨です。候補ウィジェットのサイズ変更ができるようになりました。",
 		"この設定は非推奨です。代わりに、\'editor.suggest.showKeywords\' や \'editor.suggest.showSnippets\' などの個別の設定を使用してください。",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.ja", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"読み込んでいます...",
+		"パフォーマンス上の理由からトークン化はスキップされます。その長い行の長さは `editor.maxTokenizationLineLength` で構成できます。",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"問題の表示",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"候補ウィジェットの境界線色。",
 		"候補ウィジェットの前景色。",
 		"候補ウィジェット内で選択済み入力の前景色。",
+		"候補ウィジェット内で選択済み入力のアイコン前景色。",
 		"候補ウィジェット内で選択済みエントリの背景色。",
 		"候補のウィジェット内で一致したハイライトの色。",
 		"項目がフォーカスされている場合に、候補ウィジェットでの一致の強調表示の色です。",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.ja", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"普通ではない行終端記号",
 		"普通ではない行終端記号が検出されました",
-		"このファイルには、行区切り文字 (LS) や段落区切り記号 (PS) などの特殊な行の終端文字が 1 つ以上含まれています。\r\n\r\nそれらの終端文字はファイルから削除することをお勧めします。これは \'editor.unusualLineTerminators\' を使用して構成できます。",
-		"このファイルを修正",
-		"このファイルでは問題を無視する",
+		"このファイル \'{0}\' には、行区切り文字 (LS) や段落区切り記号 (PS) などの特殊な行の終端文字が 1 つ以上含まれています。\r\n\r\nそれらをファイルから削除することをお勧めします。これは \'editor.unusualLineTerminators\' を使用して構成できます。",
+		"特殊な行の終端記号を削除する",
+		"無視する",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"変数の読み取りなど、読み取りアクセス中のシンボルの背景色。下にある装飾を隠さないために、色は不透過であってはなりません。",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.ja", {
 		"最近使用したもの",
 		"その他のコマンド",
 		"コマンド \'{0}\' でエラー ({1}) が発生しました",
-		"OK",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"グローバル コマンド",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"コントラストを強めるために、他の要素と隔てる追加の境界線。",
 		"コントラストを強めるために、アクティブな他要素と隔てる追加の境界線。",
 		"テキスト内のリンクの前景色。",
+		"クリックされたときとマウスをホバーしたときのテキスト内のリンクの前景色。",
 		"テキスト内のコード ブロックの背景色。",
 		"エディター内の検索/置換窓など、エディター ウィジェットの影の色。",
 		"入力ボックスの背景。",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.ja", {
 		"リストやツリーがアクティブな場合の、フォーカスされた項目のリストやツリーのアウトライン色。アクティブなリストやツリーにはキーボード フォーカスがあり、非アクティブにはこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストがアクティブのとき、選択された項目のツリーリスト前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
+		"ツリーリストがアクティブのとき、選択された項目のツリーリストのアイコン前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、選択された項目のツリーリスト前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
+		"ツリーリストが非アクティブのとき、選択された項目のツリーリストのアイコン前景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"ツリーリストが非アクティブのとき、フォーカスされた項目のツリーリスト背景色。アクティブなツリーリストはキーボード フォーカスがあり、非アクティブではこれがありません。",
 		"リストやツリーが非アクティブな場合の、フォーカスされた項目のリストやツリーのアウトライン色。アクティブなリストやツリーにはキーボード フォーカスがあり、非アクティブにはこれがありません。",
 		"マウス操作で項目をホバーするときのツリーリスト背景。",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"インデント ガイドのツリー ストロークの色。",
 		"代わりに quickInputList.focusBackground を使用してください",
 		"フォーカスされた項目のクイック選択の前景色。",
+		"フォーカスされた項目のクイック選択のアイコン前景色。",
 		"フォーカスされた項目のクイック選択の背景色。",
 		"メニューの境界線色。",
 		"メニュー項目の前景色。",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.ja", {
 		"キャンセル",
 		"元に戻すまたはやり直し操作が既に実行されているため、\'{0}\' を元に戻すことはできませんでした。",
 		"\'{0}\' を元に戻しますか?",
-		"元に戻す",
+		"はい",
 		"キャンセル",
 		"すべてのファイルで \'{0}\' をやり直しできませんでした。{1}",
 		"すべてのファイルで \'{0}\' をやり直しできませんでした。{1}",
