@@ -25,7 +25,7 @@ import { ICodeEditorService } from '../services/codeEditorService.js';
 import { View } from '../view/viewImpl.js';
 import { ViewUserInputEvents } from '../view/viewUserInputEvents.js';
 import { filterValidationDecorations } from '../../common/config/editorOptions.js';
-import { Cursor } from '../../common/controller/cursor.js';
+import { CursorsController } from '../../common/controller/cursor.js';
 import { CursorColumns } from '../../common/controller/cursorCommon.js';
 import { Position } from '../../common/core/position.js';
 import { Range } from '../../common/core/range.js';
@@ -1071,7 +1071,7 @@ let CodeEditorWidget = class CodeEditorWidget extends Disposable {
                     break;
                 case 5 /* CursorStateChanged */: {
                     if (e.reachedMaxCursorCount) {
-                        this._notificationService.warn(nls.localize('cursors.maximum', "The number of cursors has been limited to {0}.", Cursor.MAX_CURSOR_COUNT));
+                        this._notificationService.warn(nls.localize('cursors.maximum', "The number of cursors has been limited to {0}.", CursorsController.MAX_CURSOR_COUNT));
                     }
                     const positions = [];
                     for (let i = 0, len = e.selections.length; i < len; i++) {
