@@ -91,7 +91,7 @@ class AutoClosedAction {
         return true;
     }
 }
-export class Cursor extends Disposable {
+export class CursorsController extends Disposable {
     constructor(model, viewModel, coordinatesConverter, cursorConfig) {
         super();
         this._model = model;
@@ -159,8 +159,8 @@ export class Cursor extends Disposable {
     }
     setStates(eventsCollector, source, reason, states) {
         let reachedMaxCursorCount = false;
-        if (states !== null && states.length > Cursor.MAX_CURSOR_COUNT) {
-            states = states.slice(0, Cursor.MAX_CURSOR_COUNT);
+        if (states !== null && states.length > CursorsController.MAX_CURSOR_COUNT) {
+            states = states.slice(0, CursorsController.MAX_CURSOR_COUNT);
             reachedMaxCursorCount = true;
         }
         const oldState = new CursorModelState(this._model, this);
@@ -571,7 +571,7 @@ export class Cursor extends Disposable {
         }, eventsCollector, source);
     }
 }
-Cursor.MAX_CURSOR_COUNT = 10000;
+CursorsController.MAX_CURSOR_COUNT = 10000;
 class CommandExecutor {
     static executeCommands(model, selectionsBefore, commands) {
         const ctx = {
