@@ -3,12 +3,14 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 import * as arrays from '../../../base/common/arrays.js';
+import { LineTokens } from '../core/lineTokens.js';
 import { Position } from '../core/position.js';
 import { Range } from '../core/range.js';
 import { ModelDecorationOptions } from '../model/textModel.js';
 import * as viewEvents from '../view/viewEvents.js';
 import { PrefixSumIndexOfResult } from './prefixSumComputer.js';
-import { LineBreakData, ViewLineData } from './viewModel.js';
+import { ViewLineData } from './viewModel.js';
+import { LineInjectedText } from '../model/textModelEvents.js';
 export class CoordinatesConverter {
     constructor(lines) {
         this._lines = lines;
@@ -103,7 +105,8 @@ class LineNumberMapper {
     }
 }
 export class SplitLinesCollection {
-    constructor(model, domLineBreaksComputerFactory, monospaceLineBreaksComputerFactory, fontInfo, tabSize, wrappingStrategy, wrappingColumn, wrappingIndent) {
+    constructor(editorId, model, domLineBreaksComputerFactory, monospaceLineBreaksComputerFactory, fontInfo, tabSize, wrappingStrategy, wrappingColumn, wrappingIndent) {
+        this._editorId = editorId;
         this.model = model;
         this._validModelVersionId = -1;
         this._domLineBreaksComputerFactory = domLineBreaksComputerFactory;
@@ -126,11 +129,26 @@ export class SplitLinesCollection {
         if (resetHiddenAreas) {
             this.hiddenAreasIds = [];
         }
-        let linesContent = this.model.getLinesContent();
+        const linesContent = this.model.getLinesContent();
+        const injectedTextDecorations = this.model.getInjectedTextDecorations(this._editorId);
+        const injectedText = LineInjectedText.fromDecorations(injectedTextDecorations);
         const lineCount = linesContent.length;
         const lineBreaksComputer = this.createLineBreaksComputer();
+        const injectedTextLength = injectedText.length;
+        let injectedTextIndex = 0;
+        let nextLineNumberWithInjectedText = (injectedTextIndex < injectedTextLength ? injectedText[injectedTextIndex].lineNumber : lineCount + 1);
         for (let i = 0; i < lineCount; i++) {
-            lineBreaksComputer.addRequest(linesContent[i], previousLineBreaks ? previousLineBreaks[i] : null);
+            let lineInjectedText = null;
+            if (i + 1 === nextLineNumberWithInjectedText) {
+                // There is some injected text on this line
+                lineInjectedText = [];
+                while (i + 1 === nextLineNumberWithInjectedText && injectedTextIndex < injectedTextLength) {
+                    lineInjectedText.push(injectedText[injectedTextIndex]);
+                    injectedTextIndex++;
+                    nextLineNumberWithInjectedText = (injectedTextIndex < injectedTextLength ? injectedText[injectedTextIndex].lineNumber : lineCount + 1);
+                }
+            }
+            lineBreaksComputer.addRequest(linesContent[i], lineInjectedText, previousLineBreaks ? previousLineBreaks[i] : null);
         }
         const linesBreaks = lineBreaksComputer.finalize();
         let values = [];
@@ -301,7 +319,7 @@ export class SplitLinesCollection {
         this._constructLines(/*resetHiddenAreas*/ true, null);
     }
     onModelLinesDeleted(versionId, fromLineNumber, toLineNumber) {
-        if (versionId <= this._validModelVersionId) {
+        if (!versionId || versionId <= this._validModelVersionId) {
             // Here we check for versionId in case the lines were reconstructed in the meantime.
             // We don't want to apply stale change events on top of a newer read model state.
             return null;
@@ -313,7 +331,7 @@ export class SplitLinesCollection {
         return new viewEvents.ViewLinesDeletedEvent(outputFromLineNumber, outputToLineNumber);
     }
     onModelLinesInserted(versionId, fromLineNumber, _toLineNumber, lineBreaks) {
-        if (versionId <= this._validModelVersionId) {
+        if (!versionId || versionId <= this._validModelVersionId) {
             // Here we check for versionId in case the lines were reconstructed in the meantime.
             // We don't want to apply stale change events on top of a newer read model state.
             return null;
@@ -337,7 +355,7 @@ export class SplitLinesCollection {
         return new viewEvents.ViewLinesInsertedEvent(outputFromLineNumber, outputFromLineNumber + totalOutputLineCount - 1);
     }
     onModelLineChanged(versionId, lineNumber, lineBreakData) {
-        if (versionId <= this._validModelVersionId) {
+        if (versionId !== null && versionId <= this._validModelVersionId) {
             // Here we check for versionId in case the lines were reconstructed in the meantime.
             // We don't want to apply stale change events on top of a newer read model state.
             return [false, null, null, null];
@@ -864,13 +882,13 @@ export class SplitLine {
         return this._lineBreakData.breakOffsets.length;
     }
     getInputStartOffsetOfOutputLineIndex(outputLineIndex) {
-        return LineBreakData.getInputOffsetOfOutputPosition(this._lineBreakData.breakOffsets, outputLineIndex, 0);
+        return this._lineBreakData.getInputOffsetOfOutputPosition(outputLineIndex, 0);
     }
     getInputEndOffsetOfOutputLineIndex(model, modelLineNumber, outputLineIndex) {
         if (outputLineIndex + 1 === this._lineBreakData.breakOffsets.length) {
             return model.getLineMaxColumn(modelLineNumber) - 1;
         }
-        return LineBreakData.getInputOffsetOfOutputPosition(this._lineBreakData.breakOffsets, outputLineIndex + 1, 0);
+        return this._lineBreakData.getInputOffsetOfOutputPosition(outputLineIndex + 1, 0);
     }
     getViewLineContent(model, modelLineNumber, outputLineIndex) {
         if (!this._isVisible) {
@@ -890,11 +908,16 @@ export class SplitLine {
         return r;
     }
     getViewLineLength(model, modelLineNumber, outputLineIndex) {
+        // TODO @hediet make this method a member of LineBreakData.
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
-        let startOffset = this.getInputStartOffsetOfOutputLineIndex(outputLineIndex);
-        let endOffset = this.getInputEndOffsetOfOutputLineIndex(model, modelLineNumber, outputLineIndex);
+        // These offsets refer to model text with injected text.
+        const startOffset = outputLineIndex > 0 ? this._lineBreakData.breakOffsets[outputLineIndex - 1] : 0;
+        const endOffset = outputLineIndex < this._lineBreakData.breakOffsets.length
+            ? this._lineBreakData.breakOffsets[outputLineIndex]
+            // This case might not be possible anyway, but we clamp the value to be on the safe side.
+            : this._lineBreakData.breakOffsets[this._lineBreakData.breakOffsets.length - 1];
         let r = endOffset - startOffset;
         if (outputLineIndex > 0) {
             r = this._lineBreakData.wrappedTextIndentLength + r;
@@ -923,27 +946,43 @@ export class SplitLine {
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
-        let startOffset = this.getInputStartOffsetOfOutputLineIndex(outputLineIndex);
-        let endOffset = this.getInputEndOffsetOfOutputLineIndex(model, modelLineNumber, outputLineIndex);
-        let lineContent = model.getValueInRange({
-            startLineNumber: modelLineNumber,
-            startColumn: startOffset + 1,
-            endLineNumber: modelLineNumber,
-            endColumn: endOffset + 1
-        });
-        if (outputLineIndex > 0) {
-            lineContent = spaces(this._lineBreakData.wrappedTextIndentLength) + lineContent;
+        const lineBreakData = this._lineBreakData;
+        const deltaStartIndex = (outputLineIndex > 0 ? lineBreakData.wrappedTextIndentLength : 0);
+        const offsets = lineBreakData.injectionOffsets;
+        const texts = lineBreakData.injectionTexts;
+        let lineContent;
+        let tokens;
+        if (offsets) {
+            const lineTokens = model.getLineTokens(modelLineNumber).withInserted(offsets.map((offset, idx) => ({
+                offset,
+                text: texts[idx],
+                tokenMetadata: LineTokens.defaultTokenMetadata
+            })));
+            const startOffset = (outputLineIndex > 0 ? lineBreakData.breakOffsets[outputLineIndex - 1] : 0);
+            const endOffset = lineBreakData.breakOffsets[outputLineIndex];
+            lineContent = lineTokens.getLineContent().substring(startOffset, endOffset);
+            tokens = lineTokens.sliceAndInflate(startOffset, endOffset, deltaStartIndex);
         }
-        let minColumn = (outputLineIndex > 0 ? this._lineBreakData.wrappedTextIndentLength + 1 : 1);
-        let maxColumn = lineContent.length + 1;
-        let continuesWithWrappedLine = (outputLineIndex + 1 < this.getViewLineCount());
-        let deltaStartIndex = 0;
-        if (outputLineIndex > 0) {
-            deltaStartIndex = this._lineBreakData.wrappedTextIndentLength;
+        else {
+            const startOffset = this.getInputStartOffsetOfOutputLineIndex(outputLineIndex);
+            const endOffset = this.getInputEndOffsetOfOutputLineIndex(model, modelLineNumber, outputLineIndex);
+            const lineTokens = model.getLineTokens(modelLineNumber);
+            lineContent = model.getValueInRange({
+                startLineNumber: modelLineNumber,
+                startColumn: startOffset + 1,
+                endLineNumber: modelLineNumber,
+                endColumn: endOffset + 1
+            });
+            tokens = lineTokens.sliceAndInflate(startOffset, endOffset, deltaStartIndex);
         }
-        let lineTokens = model.getLineTokens(modelLineNumber);
-        const startVisibleColumn = (outputLineIndex === 0 ? 0 : this._lineBreakData.breakOffsetsVisibleColumn[outputLineIndex - 1]);
-        return new ViewLineData(lineContent, continuesWithWrappedLine, minColumn, maxColumn, startVisibleColumn, lineTokens.sliceAndInflate(startOffset, endOffset, deltaStartIndex));
+        if (outputLineIndex > 0) {
+            lineContent = spaces(lineBreakData.wrappedTextIndentLength) + lineContent;
+        }
+        const minColumn = (outputLineIndex > 0 ? lineBreakData.wrappedTextIndentLength + 1 : 1);
+        const maxColumn = lineContent.length + 1;
+        const continuesWithWrappedLine = (outputLineIndex + 1 < this.getViewLineCount());
+        const startVisibleColumn = (outputLineIndex === 0 ? 0 : lineBreakData.breakOffsetsVisibleColumn[outputLineIndex - 1]);
+        return new ViewLineData(lineContent, continuesWithWrappedLine, minColumn, maxColumn, startVisibleColumn, tokens);
     }
     getViewLinesData(model, modelLineNumber, fromOuputLineIndex, toOutputLineIndex, globalStartIndex, needed, result) {
         if (!this._isVisible) {
@@ -971,13 +1010,13 @@ export class SplitLine {
                 adjustedColumn -= this._lineBreakData.wrappedTextIndentLength;
             }
         }
-        return LineBreakData.getInputOffsetOfOutputPosition(this._lineBreakData.breakOffsets, outputLineIndex, adjustedColumn) + 1;
+        return this._lineBreakData.getInputOffsetOfOutputPosition(outputLineIndex, adjustedColumn) + 1;
     }
     getViewPositionOfModelPosition(deltaLineNumber, inputColumn) {
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
-        let r = LineBreakData.getOutputPositionOfInputOffset(this._lineBreakData.breakOffsets, inputColumn - 1);
+        let r = this._lineBreakData.getOutputPositionOfInputOffset(inputColumn - 1);
         let outputLineIndex = r.outputLineIndex;
         let outputColumn = r.outputOffset + 1;
         if (outputLineIndex > 0) {
@@ -990,7 +1029,7 @@ export class SplitLine {
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
-        const r = LineBreakData.getOutputPositionOfInputOffset(this._lineBreakData.breakOffsets, inputColumn - 1);
+        const r = this._lineBreakData.getOutputPositionOfInputOffset(inputColumn - 1);
         return (deltaLineNumber + r.outputLineIndex);
     }
     normalizePosition(model, modelLineNumber, outputLineIndex, outputPosition, affinity) {
@@ -1098,7 +1137,7 @@ export class IdentityLinesCollection {
     createLineBreaksComputer() {
         let result = [];
         return {
-            addRequest: (lineText, previousLineBreakData) => {
+            addRequest: (lineText, injectedText, previousLineBreakData) => {
                 result.push(null);
             },
             finalize: () => {
