@@ -8,6 +8,7 @@ import * as strings from '../../../base/common/strings.js';
 import { EDITOR_FONT_DEFAULTS, filterValidationDecorations } from '../config/editorOptions.js';
 import { Position } from '../core/position.js';
 import { Range } from '../core/range.js';
+import * as textModelEvents from '../model/textModelEvents.js';
 import { TokenizationRegistry } from '../modes.js';
 import { tokenizeLineToHTML } from '../modes/textToHtmlTokenizer.js';
 import { MinimapTokensColorTracker } from './minimapTokensColorTracker.js';
@@ -18,7 +19,7 @@ import { MinimapLinesRenderingData, ViewLineRenderingData } from './viewModel.js
 import { ViewModelDecorations } from './viewModelDecorations.js';
 import { RunOnceScheduler } from '../../../base/common/async.js';
 import * as platform from '../../../base/common/platform.js';
-import { Cursor } from '../controller/cursor.js';
+import { CursorsController } from '../controller/cursor.js';
 import { CursorConfiguration } from '../controller/cursorCommon.js';
 import { ViewModelEventDispatcher, FocusChangedEvent, ScrollChangedEvent, ViewZonesChangedEvent, ReadOnlyEditAttemptEvent } from './viewModelEventDispatcher.js';
 const USE_IDENTITY_LINES_COLLECTION = true;
@@ -46,10 +47,10 @@ export class ViewModel extends Disposable {
             const wrappingStrategy = options.get(122 /* wrappingStrategy */);
             const wrappingInfo = options.get(129 /* wrappingInfo */);
             const wrappingIndent = options.get(121 /* wrappingIndent */);
-            this._lines = new SplitLinesCollection(this.model, domLineBreaksComputerFactory, monospaceLineBreaksComputerFactory, fontInfo, this.model.getOptions().tabSize, wrappingStrategy, wrappingInfo.wrappingColumn, wrappingIndent);
+            this._lines = new SplitLinesCollection(this._editorId, this.model, domLineBreaksComputerFactory, monospaceLineBreaksComputerFactory, fontInfo, this.model.getOptions().tabSize, wrappingStrategy, wrappingInfo.wrappingColumn, wrappingIndent);
         }
         this.coordinatesConverter = this._lines.createCoordinatesConverter();
-        this._cursor = this._register(new Cursor(model, this, this.coordinatesConverter, this.cursorConfig));
+        this._cursor = this._register(new CursorsController(model, this, this.coordinatesConverter, this.cursorConfig));
         this.viewLayout = this._register(new ViewLayout(this._configuration, this.getLineCount(), scheduleAtNextAnimationFrame));
         this._register(this.viewLayout.onDidScroll((e) => {
             if (e.scrollTopChanged) {
@@ -164,25 +165,34 @@ export class ViewModel extends Disposable {
         }
     }
     _registerModelEvents() {
-        this._register(this.model.onDidChangeRawContentFast((e) => {
+        this._register(this.model.onDidChangeContentOrInjectedText((e) => {
             try {
                 const eventsCollector = this._eventDispatcher.beginEmitViewEvents();
                 let hadOtherModelChange = false;
                 let hadModelLineChangeThatChangedLineMapping = false;
                 const changes = e.changes;
-                const versionId = e.versionId;
+                const versionId = (e instanceof textModelEvents.ModelRawContentChangedEvent ? e.versionId : null);
                 // Do a first pass to compute line mappings, and a second pass to actually interpret them
                 const lineBreaksComputer = this._lines.createLineBreaksComputer();
                 for (const change of changes) {
                     switch (change.changeType) {
                         case 4 /* LinesInserted */: {
-                            for (const line of change.detail) {
-                                lineBreaksComputer.addRequest(line, null);
+                            for (let lineIdx = 0; lineIdx < change.detail.length; lineIdx++) {
+                                const line = change.detail[lineIdx];
+                                let injectedText = change.injectedTexts[lineIdx];
+                                if (injectedText) {
+                                    injectedText = injectedText.filter(element => (!element.ownerId || element.ownerId === this._editorId));
+                                }
+                                lineBreaksComputer.addRequest(line, injectedText, null);
                             }
                             break;
                         }
                         case 2 /* LineChanged */: {
-                            lineBreaksComputer.addRequest(change.detail, null);
+                            let injectedText = null;
+                            if (change.injectedText) {
+                                injectedText = change.injectedText.filter(element => (!element.ownerId || element.ownerId === this._editorId));
+                            }
+                            lineBreaksComputer.addRequest(change.detail, injectedText, null);
                             break;
                         }
                     }
@@ -243,7 +253,9 @@ export class ViewModel extends Disposable {
                         }
                     }
                 }
-                this._lines.acceptVersionId(versionId);
+                if (versionId !== null) {
+                    this._lines.acceptVersionId(versionId);
+                }
                 this.viewLayout.onHeightMaybeChanged();
                 if (!hadOtherModelChange && hadModelLineChangeThatChangedLineMapping) {
                     eventsCollector.emitViewEvent(new viewEvents.ViewLineMappingChangedEvent());
@@ -268,12 +280,14 @@ export class ViewModel extends Disposable {
                     this.viewLayout.setScrollPosition({ scrollTop: viewPositionTop + this._viewportStartLineDelta }, 1 /* Immediate */);
                 }
             }
-            try {
-                const eventsCollector = this._eventDispatcher.beginEmitViewEvents();
-                this._cursor.onModelContentChanged(eventsCollector, e);
-            }
-            finally {
-                this._eventDispatcher.endEmitViewEvents();
+            if (e instanceof textModelEvents.ModelRawContentChangedEvent) {
+                try {
+                    const eventsCollector = this._eventDispatcher.beginEmitViewEvents();
+                    this._cursor.onModelContentChanged(eventsCollector, e);
+                }
+                finally {
+                    this._eventDispatcher.endEmitViewEvents();
+                }
             }
         }));
         this._register(this.model.onDidChangeTokens((e) => {
