@@ -51,14 +51,14 @@ export class SimpleModel {
     constructor(model) {
         this.disposed = false;
         this.model = model;
-        this._onDispose = new Emitter();
+        this._onWillDispose = new Emitter();
     }
     get textEditorModel() {
         return this.model;
     }
     dispose() {
         this.disposed = true;
-        this._onDispose.fire();
+        this._onWillDispose.fire();
     }
 }
 function withTypedEditor(widget, codeEditorCallback, diffEditorCallback) {
@@ -105,7 +105,9 @@ export class SimpleEditorProgressService {
         return SimpleEditorProgressService.NULL_PROGRESS_RUNNER;
     }
     showWhile(promise, delay) {
-        return Promise.resolve(undefined);
+        return __awaiter(this, void 0, void 0, function* () {
+            yield promise;
+        });
     }
 }
 SimpleEditorProgressService.NULL_PROGRESS_RUNNER = {
@@ -166,6 +168,7 @@ export class StandaloneCommandService {
     constructor(instantiationService) {
         this._onWillExecuteCommand = new Emitter();
         this._onDidExecuteCommand = new Emitter();
+        this.onDidExecuteCommand = this._onDidExecuteCommand.event;
         this._instantiationService = instantiationService;
     }
     executeCommand(id, ...args) {
@@ -189,14 +192,23 @@ export class StandaloneKeybindingService extends AbstractKeybindingService {
         super(contextKeyService, commandService, telemetryService, notificationService, logService);
         this._cachedResolver = null;
         this._dynamicKeybindings = [];
+        // for standard keybindings
         this._register(dom.addDisposableListener(domNode, dom.EventType.KEY_DOWN, (e) => {
-            let keyEvent = new StandardKeyboardEvent(e);
-            let shouldPreventDefault = this._dispatch(keyEvent, keyEvent.target);
+            const keyEvent = new StandardKeyboardEvent(e);
+            const shouldPreventDefault = this._dispatch(keyEvent, keyEvent.target);
             if (shouldPreventDefault) {
                 keyEvent.preventDefault();
                 keyEvent.stopPropagation();
             }
         }));
+        // for single modifier chord keybindings (e.g. shift shift)
+        this._register(dom.addDisposableListener(window, dom.EventType.KEY_UP, (e) => {
+            const keyEvent = new StandardKeyboardEvent(e);
+            const shouldPreventDefault = this._singleModifierDispatch(keyEvent, keyEvent.target);
+            if (shouldPreventDefault) {
+                keyEvent.preventDefault();
+            }
+        }));
     }
     addDynamicKeybinding(commandId, _keybinding, handler, when) {
         const keybinding = createKeybinding(_keybinding, OS);
@@ -208,7 +220,8 @@ export class StandaloneKeybindingService extends AbstractKeybindingService {
                 when: when,
                 weight1: 1000,
                 weight2: 0,
-                extensionId: null
+                extensionId: null,
+                isBuiltinExtension: false
             });
             toDispose.add(toDisposable(() => {
                 for (let i = 0; i < this._dynamicKeybindings.length; i++) {
@@ -247,12 +260,12 @@ export class StandaloneKeybindingService extends AbstractKeybindingService {
             const keybinding = item.keybinding;
             if (!keybinding) {
                 // This might be a removal keybinding item in user settings => accept it
-                result[resultLen++] = new ResolvedKeybindingItem(undefined, item.command, item.commandArgs, when, isDefault, null);
+                result[resultLen++] = new ResolvedKeybindingItem(undefined, item.command, item.commandArgs, when, isDefault, null, false);
             }
             else {
                 const resolvedKeybindings = this.resolveKeybinding(keybinding);
                 for (const resolvedKeybinding of resolvedKeybindings) {
-                    result[resultLen++] = new ResolvedKeybindingItem(resolvedKeybinding, item.command, item.commandArgs, when, isDefault, null);
+                    result[resultLen++] = new ResolvedKeybindingItem(resolvedKeybinding, item.command, item.commandArgs, when, isDefault, null, false);
                 }
             }
         }
@@ -352,12 +365,9 @@ export class SimpleWorkspaceContextService {
     getWorkspace() {
         return this.workspace;
     }
-    getWorkspaceFolder(resource) {
-        return resource && resource.scheme === SimpleWorkspaceContextService.SCHEME ? this.workspace.folders[0] : null;
-    }
 }
 SimpleWorkspaceContextService.SCHEME = 'inmemory';
-export function applyConfigurationValues(configurationService, source, isDiffEditor) {
+export function updateConfigurationService(configurationService, source, isDiffEditor) {
     if (!source) {
         return;
     }
@@ -433,7 +443,7 @@ export class SimpleLayoutService {
     constructor(_codeEditorService, _container) {
         this._codeEditorService = _codeEditorService;
         this._container = _container;
-        this.onLayout = Event.None;
+        this.onDidLayout = Event.None;
     }
     get dimension() {
         if (!this._dimension) {
