@@ -21,8 +21,7 @@ var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, ge
     });
 };
 import './menuEntryActionViewItem.css';
-import { asCSSUrl, ModifierKeyEmitter } from '../../../base/browser/dom.js';
-import { domEvent } from '../../../base/browser/event.js';
+import { addDisposableListener, asCSSUrl, ModifierKeyEmitter } from '../../../base/browser/dom.js';
 import { Separator, SubmenuAction } from '../../../base/common/actions.js';
 import { toDisposable, MutableDisposable, DisposableStore } from '../../../base/common/lifecycle.js';
 import { localize } from '../../../nls.js';
@@ -35,6 +34,7 @@ import { ThemeIcon } from '../../theme/common/themeService.js';
 import { ActionViewItem } from '../../../base/browser/ui/actionbar/actionViewItems.js';
 import { DropdownMenuActionViewItem } from '../../../base/browser/ui/dropdown/dropdownActionViewItem.js';
 import { isWindows, isLinux, OS } from '../../../base/common/platform.js';
+import { IContextKeyService } from '../../contextkey/common/contextkey.js';
 export function createAndFillInActionBarActions(menu, options, target, primaryGroup, primaryMaxCount, shouldInlineSubmenu, useSeparatorsInPrimaryActions) {
     const groups = menu.getActions(options);
     const isPrimaryAction = typeof primaryGroup === 'string' ? (actionGroup) => actionGroup === primaryGroup : primaryGroup;
@@ -106,10 +106,11 @@ function fillInActions(groups, target, useAlternativeActions, isPrimaryAction =
     }
 }
 let MenuEntryActionViewItem = class MenuEntryActionViewItem extends ActionViewItem {
-    constructor(_action, _keybindingService, _notificationService) {
-        super(undefined, _action, { icon: !!(_action.class || _action.item.icon), label: !_action.class && !_action.item.icon });
+    constructor(_action, options, _keybindingService, _notificationService, _contextKeyService) {
+        super(undefined, _action, { icon: !!(_action.class || _action.item.icon), label: !_action.class && !_action.item.icon, draggable: options === null || options === void 0 ? void 0 : options.draggable });
         this._keybindingService = _keybindingService;
         this._notificationService = _notificationService;
+        this._contextKeyService = _contextKeyService;
         this._wantsAltCommand = false;
         this._itemClassDispose = this._register(new MutableDisposable());
         this._altKey = ModifierKeyEmitter.getInstance();
@@ -153,11 +154,11 @@ let MenuEntryActionViewItem = class MenuEntryActionViewItem extends ActionViewIt
                 updateAltState();
             }));
         }
-        this._register(domEvent(container, 'mouseleave')(_ => {
+        this._register(addDisposableListener(container, 'mouseleave', _ => {
             mouseOver = false;
             updateAltState();
         }));
-        this._register(domEvent(container, 'mouseenter')(e => {
+        this._register(addDisposableListener(container, 'mouseenter', _ => {
             mouseOver = true;
             updateAltState();
         }));
@@ -169,7 +170,7 @@ let MenuEntryActionViewItem = class MenuEntryActionViewItem extends ActionViewIt
     }
     updateTooltip() {
         if (this.label) {
-            const keybinding = this._keybindingService.lookupKeybinding(this._commandAction.id);
+            const keybinding = this._keybindingService.lookupKeybinding(this._commandAction.id, this._contextKeyService);
             const keybindingLabel = keybinding && keybinding.getLabel();
             const tooltip = this._commandAction.tooltip || this._commandAction.label;
             let title = keybindingLabel
@@ -177,7 +178,7 @@ let MenuEntryActionViewItem = class MenuEntryActionViewItem extends ActionViewIt
                 : tooltip;
             if (!this._wantsAltCommand && this._menuItemAction.alt) {
                 const altTooltip = this._menuItemAction.alt.tooltip || this._menuItemAction.alt.label;
-                const altKeybinding = this._keybindingService.lookupKeybinding(this._menuItemAction.alt.id);
+                const altKeybinding = this._keybindingService.lookupKeybinding(this._menuItemAction.alt.id, this._contextKeyService);
                 const altKeybindingLabel = altKeybinding && altKeybinding.getLabel();
                 const altTitleSection = altKeybindingLabel
                     ? localize('titleAndKb', "{0} ({1})", altTooltip, altKeybindingLabel)
@@ -236,8 +237,9 @@ let MenuEntryActionViewItem = class MenuEntryActionViewItem extends ActionViewIt
     }
 };
 MenuEntryActionViewItem = __decorate([
-    __param(1, IKeybindingService),
-    __param(2, INotificationService)
+    __param(2, IKeybindingService),
+    __param(3, INotificationService),
+    __param(4, IContextKeyService)
 ], MenuEntryActionViewItem);
 export { MenuEntryActionViewItem };
 let SubmenuEntryActionViewItem = class SubmenuEntryActionViewItem extends DropdownMenuActionViewItem {
@@ -273,7 +275,7 @@ export { SubmenuEntryActionViewItem };
  */
 export function createActionViewItem(instaService, action) {
     if (action instanceof MenuItemAction) {
-        return instaService.createInstance(MenuEntryActionViewItem, action);
+        return instaService.createInstance(MenuEntryActionViewItem, action, undefined);
     }
     else if (action instanceof SubmenuItemAction) {
         return instaService.createInstance(SubmenuEntryActionViewItem, action);
