@@ -6,6 +6,8 @@ import * as nls from '../../../nls.js';
 import { IntervalTimer, TimeoutTimer } from '../../../base/common/async.js';
 import { Emitter, Event } from '../../../base/common/event.js';
 import { Disposable } from '../../../base/common/lifecycle.js';
+// Skip logging for high-frequency text editing commands
+const HIGH_FREQ_COMMANDS = /^(cursor|delete)/;
 export class AbstractKeybindingService extends Disposable {
     constructor(_contextKeyService, _commandService, _telemetryService, _notificationService, _logService) {
         super();
@@ -37,7 +39,7 @@ export class AbstractKeybindingService extends Disposable {
         return this._getResolver().getKeybindings();
     }
     lookupKeybinding(commandId, context) {
-        const result = this._getResolver().lookupPrimaryKeybinding(commandId, context);
+        const result = this._getResolver().lookupPrimaryKeybinding(commandId, context || this._contextKeyService);
         if (!result) {
             return undefined;
         }
@@ -163,7 +165,9 @@ export class AbstractKeybindingService extends Disposable {
             else {
                 this._commandService.executeCommand(resolveResult.commandId, resolveResult.commandArgs).then(undefined, err => this._notificationService.warn(err));
             }
-            this._telemetryService.publicLog2('workbenchActionExecuted', { id: resolveResult.commandId, from: 'keybinding' });
+            if (!HIGH_FREQ_COMMANDS.test(resolveResult.commandId)) {
+                this._telemetryService.publicLog2('workbenchActionExecuted', { id: resolveResult.commandId, from: 'keybinding' });
+            }
         }
         return shouldPreventDefault;
     }
