@@ -1,5 +1,13 @@
 'use strict'
 
+class AbortError extends Error {
+  constructor () {
+    super('The operation was aborted')
+    this.code = 'ABORT_ERR'
+    this.name = 'AbortError'
+  }
+}
+
 class UndiciError extends Error {
   constructor (message) {
     super(message)
@@ -8,6 +16,16 @@ class UndiciError extends Error {
   }
 }
 
+class ConnectTimeoutError extends UndiciError {
+  constructor (message) {
+    super(message)
+    Error.captureStackTrace(this, ConnectTimeoutError)
+    this.name = 'ConnectTimeoutError'
+    this.message = message || 'Connect Timeout Error'
+    this.code = 'UND_ERR_CONNECT_TIMEOUT'
+  }
+}
+
 class HeadersTimeoutError extends UndiciError {
   constructor (message) {
     super(message)
@@ -18,6 +36,16 @@ class HeadersTimeoutError extends UndiciError {
   }
 }
 
+class HeadersOverflowError extends UndiciError {
+  constructor (message) {
+    super(message)
+    Error.captureStackTrace(this, HeadersOverflowError)
+    this.name = 'HeadersOverflowError'
+    this.message = message || 'Headers Overflow Error'
+    this.code = 'UND_ERR_HEADERS_OVERFLOW'
+  }
+}
+
 class BodyTimeoutError extends UndiciError {
   constructor (message) {
     super(message)
@@ -33,7 +61,7 @@ class InvalidArgumentError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, InvalidArgumentError)
     this.name = 'InvalidArgumentError'
-    this.message = message || /* istanbul ignore next */ 'Invalid Argument Error'
+    this.message = message || 'Invalid Argument Error'
     this.code = 'UND_ERR_INVALID_ARG'
   }
 }
@@ -43,7 +71,7 @@ class InvalidReturnValueError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, InvalidReturnValueError)
     this.name = 'InvalidReturnValueError'
-    this.message = message || /* istanbul ignore next */ 'Invalid Return Value Error'
+    this.message = message || 'Invalid Return Value Error'
     this.code = 'UND_ERR_INVALID_RETURN_VALUE'
   }
 }
@@ -52,8 +80,8 @@ class RequestAbortedError extends UndiciError {
   constructor (message) {
     super(message)
     Error.captureStackTrace(this, RequestAbortedError)
-    this.name = 'RequestAbortedError'
-    this.message = message || /* istanbul ignore next */ 'Request aborted'
+    this.name = 'AbortError'
+    this.message = message || 'Request aborted'
     this.code = 'UND_ERR_ABORTED'
   }
 }
@@ -63,18 +91,28 @@ class InformationalError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, InformationalError)
     this.name = 'InformationalError'
-    this.message = message || /* istanbul ignore next */ 'Request information'
+    this.message = message || 'Request information'
     this.code = 'UND_ERR_INFO'
   }
 }
 
-class ContentLengthMismatchError extends UndiciError {
+class RequestContentLengthMismatchError extends UndiciError {
   constructor (message) {
     super(message)
-    Error.captureStackTrace(this, ContentLengthMismatchError)
-    this.name = 'ContentLengthMismatchError'
-    this.message = message || /* istanbul ignore next */ 'Request body length does not match content-length header'
-    this.code = 'UND_ERR_CONTENT_LENGTH_MISMATCH'
+    Error.captureStackTrace(this, RequestContentLengthMismatchError)
+    this.name = 'RequestContentLengthMismatchError'
+    this.message = message || 'Request body length does not match content-length header'
+    this.code = 'UND_ERR_REQ_CONTENT_LENGTH_MISMATCH'
+  }
+}
+
+class ResponseContentLengthMismatchError extends UndiciError {
+  constructor (message) {
+    super(message)
+    Error.captureStackTrace(this, ResponseContentLengthMismatchError)
+    this.name = 'ResponseContentLengthMismatchError'
+    this.message = message || 'Response body length does not match content-length header'
+    this.code = 'UND_ERR_RES_CONTENT_LENGTH_MISMATCH'
   }
 }
 
@@ -83,7 +121,7 @@ class TrailerMismatchError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, TrailerMismatchError)
     this.name = 'TrailerMismatchError'
-    this.message = message || /* istanbul ignore next */ 'Trailers does not match trailer header'
+    this.message = message || 'Trailers does not match trailer header'
     this.code = 'UND_ERR_TRAILER_MISMATCH'
   }
 }
@@ -93,7 +131,7 @@ class ClientDestroyedError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, ClientDestroyedError)
     this.name = 'ClientDestroyedError'
-    this.message = message || /* istanbul ignore next */ 'The client is destroyed'
+    this.message = message || 'The client is destroyed'
     this.code = 'UND_ERR_DESTROYED'
   }
 }
@@ -103,18 +141,19 @@ class ClientClosedError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, ClientClosedError)
     this.name = 'ClientClosedError'
-    this.message = message || /* istanbul ignore next */ 'The client is closed'
+    this.message = message || 'The client is closed'
     this.code = 'UND_ERR_CLOSED'
   }
 }
 
 class SocketError extends UndiciError {
-  constructor (message) {
+  constructor (message, socket) {
     super(message)
     Error.captureStackTrace(this, SocketError)
     this.name = 'SocketError'
-    this.message = message || /* istanbul ignore next */ 'Socket error'
+    this.message = message || 'Socket error'
     this.code = 'UND_ERR_SOCKET'
+    this.socket = socket
   }
 }
 
@@ -123,16 +162,30 @@ class NotSupportedError extends UndiciError {
     super(message)
     Error.captureStackTrace(this, NotSupportedError)
     this.name = 'NotSupportedError'
-    this.message = message || /* istanbul ignore next */ 'Not supported error'
+    this.message = message || 'Not supported error'
     this.code = 'UND_ERR_NOT_SUPPORTED'
   }
 }
 
+class HTTPParserError extends Error {
+  constructor (message, code, data) {
+    super(message)
+    Error.captureStackTrace(this, HTTPParserError)
+    this.name = 'HTTPParserError'
+    this.code = code ? `HPE_${code}` : undefined
+    this.data = data ? data.toString() : undefined
+  }
+}
+
 module.exports = {
+  AbortError,
+  HTTPParserError,
   UndiciError,
   HeadersTimeoutError,
+  HeadersOverflowError,
   BodyTimeoutError,
-  ContentLengthMismatchError,
+  RequestContentLengthMismatchError,
+  ConnectTimeoutError,
   TrailerMismatchError,
   InvalidArgumentError,
   InvalidReturnValueError,
@@ -141,5 +194,6 @@ module.exports = {
   ClientClosedError,
   InformationalError,
   SocketError,
-  NotSupportedError
+  NotSupportedError,
+  ResponseContentLengthMismatchError
 }
