@@ -143,12 +143,14 @@ function buildRouting (options) {
       }
     }
 
+    const path = opts.url || opts.path
+
     if (!opts.handler) {
-      throw new Error(`Missing handler function for ${opts.method}:${opts.url} route.`)
+      throw new Error(`Missing handler function for ${opts.method}:${path} route.`)
     }
 
     if (opts.errorHandler !== undefined && typeof opts.errorHandler !== 'function') {
-      throw new Error(`Error Handler for ${opts.method}:${opts.url} route, if defined, must be a function`)
+      throw new Error(`Error Handler for ${opts.method}:${path} route, if defined, must be a function`)
     }
 
     validateBodyLimitOption(opts.bodyLimit)
@@ -156,7 +158,6 @@ function buildRouting (options) {
     const prefix = this[kRoutePrefix]
 
     this.after((notHandledErr, done) => {
-      const path = opts.url || opts.path
       if (path === '/' && prefix.length && opts.method !== 'HEAD') {
         switch (opts.prefixTrailingSlash) {
           case 'slash':
@@ -247,7 +248,7 @@ function buildRouting (options) {
         opts.schemaErrorFormatter || this[kSchemaErrorFormatter]
       )
 
-      const headRouteExists = router.find('HEAD', path) != null
+      const headRouteExists = router.find('HEAD', url) != null
 
       try {
         router.on(opts.method, opts.url, { constraints }, routeHandler, context)
@@ -296,7 +297,7 @@ function buildRouting (options) {
         fourOhFour.setContext(this, context)
 
         if (opts.schema) {
-          context.schema = normalizeSchema(context.schema)
+          context.schema = normalizeSchema(context.schema, this.initialConfig)
 
           const schemaController = this[kSchemaController]
           if (!opts.validatorCompiler && (opts.schema.body || opts.schema.headers || opts.schema.querystring || opts.schema.params)) {
@@ -345,15 +346,18 @@ function buildRouting (options) {
 
     const id = req.headers[requestIdHeader] || genReqId(req)
 
+    const loggerBinding = {
+      [requestIdLogLabel]: id
+    }
+
     const loggerOpts = {
-      [requestIdLogLabel]: id,
       level: context.logLevel
     }
 
     if (context.logSerializers) {
       loggerOpts.serializers = context.logSerializers
     }
-    const childLogger = logger.child(loggerOpts)
+    const childLogger = logger.child(loggerBinding, loggerOpts)
     childLogger[kDisableRequestLogging] = disableRequestLogging
 
     const queryPrefix = req.url.indexOf('?')
