@@ -43,7 +43,7 @@ Schemas.prototype.getSchema = function (schemaId) {
   return this.store[schemaId]
 }
 
-function normalizeSchema (routeSchemas) {
+function normalizeSchema (routeSchemas, serverOptions) {
   if (routeSchemas[kSchemaVisited]) {
     return routeSchemas
   }
@@ -67,25 +67,25 @@ function normalizeSchema (routeSchemas) {
   }
 
   if (routeSchemas.body) {
-    routeSchemas.body = getSchemaAnyway(routeSchemas.body)
+    routeSchemas.body = getSchemaAnyway(routeSchemas.body, serverOptions.jsonShorthand)
   }
 
   if (routeSchemas.headers) {
-    routeSchemas.headers = getSchemaAnyway(routeSchemas.headers)
+    routeSchemas.headers = getSchemaAnyway(routeSchemas.headers, serverOptions.jsonShorthand)
   }
 
   if (routeSchemas.querystring) {
-    routeSchemas.querystring = getSchemaAnyway(routeSchemas.querystring)
+    routeSchemas.querystring = getSchemaAnyway(routeSchemas.querystring, serverOptions.jsonShorthand)
   }
 
   if (routeSchemas.params) {
-    routeSchemas.params = getSchemaAnyway(routeSchemas.params)
+    routeSchemas.params = getSchemaAnyway(routeSchemas.params, serverOptions.jsonShorthand)
   }
 
   if (routeSchemas.response) {
     const httpCodes = Object.keys(routeSchemas.response)
     for (const code of httpCodes) {
-      routeSchemas.response[code] = getSchemaAnyway(routeSchemas.response[code])
+      routeSchemas.response[code] = getSchemaAnyway(routeSchemas.response[code], serverOptions.jsonShorthand)
     }
   }
 
@@ -110,8 +110,8 @@ function generateFluentSchema (schema) {
   }
 }
 
-function getSchemaAnyway (schema) {
-  if (schema.$ref || schema.oneOf || schema.allOf || schema.anyOf || schema.$merge || schema.$patch) return schema
+function getSchemaAnyway (schema, jsonShorthand) {
+  if (!jsonShorthand || schema.$ref || schema.oneOf || schema.allOf || schema.anyOf || schema.$merge || schema.$patch) return schema
   if (!schema.type && !schema.properties) {
     return {
       type: 'object',
