@@ -32,8 +32,6 @@ var RelayStoreReactFlightUtils = require('./RelayStoreReactFlightUtils');
 
 var RelayStoreSubscriptions = require('./RelayStoreSubscriptions');
 
-var RelayStoreSubscriptionsUsingMapByID = require('./RelayStoreSubscriptionsUsingMapByID');
-
 var RelayStoreUtils = require('./RelayStoreUtils');
 
 var deepFreeze = require('../util/deepFreeze');
@@ -44,9 +42,16 @@ var invariant = require('invariant');
 
 var resolveImmediate = require('../util/resolveImmediate');
 
-var _require = require('./RelayStoreUtils'),
-    ROOT_ID = _require.ROOT_ID,
-    ROOT_TYPE = _require.ROOT_TYPE;
+var _require = require('../multi-actor-environment/ActorIdentifier'),
+    INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE = _require.INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE,
+    assertInternalActorIndentifier = _require.assertInternalActorIndentifier;
+
+var _require2 = require('./RelayStoreUtils'),
+    ROOT_ID = _require2.ROOT_ID,
+    ROOT_TYPE = _require2.ROOT_TYPE;
+
+var _require3 = require('./ResolverCache'),
+    RecordResolverCache = _require3.RecordResolverCache;
 
 var DEFAULT_RELEASE_BUFFER_SIZE = 10;
 /**
@@ -108,7 +113,10 @@ var RelayModernStore = /*#__PURE__*/function () {
     this._releaseBuffer = [];
     this._roots = new Map();
     this._shouldScheduleGC = false;
-    this._storeSubscriptions = RelayFeatureFlags.ENABLE_STORE_SUBSCRIPTIONS_REFACTOR === true ? new RelayStoreSubscriptionsUsingMapByID(options === null || options === void 0 ? void 0 : options.log) : new RelayStoreSubscriptions(options === null || options === void 0 ? void 0 : options.log);
+    this._resolverCache = new RecordResolverCache(function () {
+      return _this._getMutableRecordSource();
+    });
+    this._storeSubscriptions = new RelayStoreSubscriptions(options === null || options === void 0 ? void 0 : options.log, this._resolverCache);
     this._updatedRecordIDs = new Set();
     this._shouldProcessClientComponents = options === null || options === void 0 ? void 0 : options.shouldProcessClientComponents;
     initializeRecordSource(this._recordSource);
@@ -122,11 +130,19 @@ var RelayModernStore = /*#__PURE__*/function () {
     return (_this$_optimisticSour = this._optimisticSource) !== null && _this$_optimisticSour !== void 0 ? _this$_optimisticSour : this._recordSource;
   };
 
+  _proto._getMutableRecordSource = function _getMutableRecordSource() {
+    var _this$_optimisticSour2;
+
+    return (_this$_optimisticSour2 = this._optimisticSource) !== null && _this$_optimisticSour2 !== void 0 ? _this$_optimisticSour2 : this._recordSource;
+  };
+
   _proto.check = function check(operation, options) {
-    var _this$_optimisticSour2, _options$target, _options$handlers;
+    var _options$handlers, _options$getSourceFor, _options$getTargetFor, _options$defaultActor;
 
     var selector = operation.root;
-    var source = (_this$_optimisticSour2 = this._optimisticSource) !== null && _this$_optimisticSour2 !== void 0 ? _this$_optimisticSour2 : this._recordSource;
+
+    var source = this._getMutableRecordSource();
+
     var globalInvalidationEpoch = this._globalInvalidationEpoch;
 
     var rootEntry = this._roots.get(operation.request.identifier);
@@ -135,7 +151,7 @@ var RelayModernStore = /*#__PURE__*/function () {
 
     if (globalInvalidationEpoch != null) {
       // If so, check if the operation we're checking was last written
-      // before or after invalidation occured.
+      // before or after invalidation occurred.
       if (operationLastWrittenAt == null || operationLastWrittenAt <= globalInvalidationEpoch) {
         // If the operation was written /before/ global invalidation occurred,
         // or if this operation has never been written to the store before,
@@ -147,9 +163,16 @@ var RelayModernStore = /*#__PURE__*/function () {
       }
     }
 
-    var target = (_options$target = options === null || options === void 0 ? void 0 : options.target) !== null && _options$target !== void 0 ? _options$target : source;
     var handlers = (_options$handlers = options === null || options === void 0 ? void 0 : options.handlers) !== null && _options$handlers !== void 0 ? _options$handlers : [];
-    var operationAvailability = DataChecker.check(source, target, selector, handlers, this._operationLoader, this._getDataID, this._shouldProcessClientComponents);
+    var getSourceForActor = (_options$getSourceFor = options === null || options === void 0 ? void 0 : options.getSourceForActor) !== null && _options$getSourceFor !== void 0 ? _options$getSourceFor : function (actorIdentifier) {
+      assertInternalActorIndentifier(actorIdentifier);
+      return source;
+    };
+    var getTargetForActor = (_options$getTargetFor = options === null || options === void 0 ? void 0 : options.getTargetForActor) !== null && _options$getTargetFor !== void 0 ? _options$getTargetFor : function (actorIdentifier) {
+      assertInternalActorIndentifier(actorIdentifier);
+      return source;
+    };
+    var operationAvailability = DataChecker.check(getSourceForActor, getTargetForActor, (_options$defaultActor = options === null || options === void 0 ? void 0 : options.defaultActorIdentifier) !== null && _options$defaultActor !== void 0 ? _options$defaultActor : INTERNAL_ACTOR_IDENTIFIER_DO_NOT_USE, selector, handlers, this._operationLoader, this._getDataID, this._shouldProcessClientComponents);
     return getAvailabilityStatus(operationAvailability, operationLastWrittenAt, rootEntry === null || rootEntry === void 0 ? void 0 : rootEntry.fetchTime, this._queryCacheExpirationTime);
   };
 
@@ -234,7 +257,7 @@ var RelayModernStore = /*#__PURE__*/function () {
 
   _proto.lookup = function lookup(selector) {
     var source = this.getSource();
-    var snapshot = RelayReader.read(source, selector);
+    var snapshot = RelayReader.read(source, selector, this._resolverCache);
 
     if (process.env.NODE_ENV !== "production") {
       deepFreeze(snapshot);
@@ -264,6 +287,14 @@ var RelayModernStore = /*#__PURE__*/function () {
       this._globalInvalidationEpoch = this._currentWriteEpoch;
     }
 
+    if (RelayFeatureFlags.ENABLE_RELAY_RESOLVERS) {
+      // When a record is updated, we need to also handle records that depend on it,
+      // specifically Relay Resolver result records containing results based on the
+      // updated records. This both adds to updatedRecordIDs and invalidates any
+      // cached data as needed.
+      this._resolverCache.invalidateDataIDs(this._updatedRecordIDs);
+    }
+
     var source = this.getSource();
     var updatedOwners = [];
 
@@ -322,9 +353,8 @@ var RelayModernStore = /*#__PURE__*/function () {
   };
 
   _proto.publish = function publish(source, idsMarkedForInvalidation) {
-    var _this$_optimisticSour3;
+    var target = this._getMutableRecordSource();
 
-    var target = (_this$_optimisticSour3 = this._optimisticSource) !== null && _this$_optimisticSour3 !== void 0 ? _this$_optimisticSour3 : this._recordSource;
     updateTargetFromSource(target, source, // We increment the current epoch at the end of the set of updates,
     // in notify(). Here, we pass what will be the incremented value of
     // the epoch to use to write to invalidated records.
@@ -375,6 +405,10 @@ var RelayModernStore = /*#__PURE__*/function () {
 
   _proto.toJSON = function toJSON() {
     return 'RelayModernStore()';
+  };
+
+  _proto.getEpoch = function getEpoch() {
+    return this._currentWriteEpoch;
   } // Internal API
   ;
 
