@@ -37,7 +37,8 @@ function fragmentSpreadVisitor(cache) {
       return traverseResult;
     }
 
-    !(fragmentSpread.args.length === 0) ? process.env.NODE_ENV !== "production" ? invariant(false, 'InlineFragmentsTransform: Cannot flatten fragment spread `%s` with ' + 'arguments. Use the `ApplyFragmentArgumentTransform` before flattening', fragmentSpread.name) : invariant(false) : void 0;
+    !(fragmentSpread.args.length === 0) ? process.env.NODE_ENV !== "production" ? invariant(false, 'InlineFragmentsTransform: Cannot flatten fragment spread `%s` with ' + 'arguments. Use the `ApplyFragmentArgumentTransform` before flattening', fragmentSpread.name) : invariant(false) : void 0; // $FlowFixMe[incompatible-use]
+
     var fragment = this.getContext().getFragment(fragmentSpread.name, fragmentSpread.loc);
     var result = {
       kind: 'InlineFragment',
@@ -49,7 +50,8 @@ function fragmentSpreadVisitor(cache) {
       metadata: fragmentSpread.metadata,
       selections: fragment.selections,
       typeCondition: fragment.type
-    };
+    }; // $FlowFixMe[incompatible-use]
+
     traverseResult = this.traverse(result);
     cache.set(fragmentSpread, traverseResult);
     return traverseResult;
