@@ -41,13 +41,15 @@ function maskTransform(context) {
 }
 
 function visitFragment(fragment, state) {
+  // $FlowFixMe[incompatible-use]
   var result = this.traverse(fragment, state);
 
   if (state.reachableArguments.length === 0) {
     return result;
   }
 
-  var joinedArgumentDefinitions = joinArgumentDefinitions(this.getContext().getSchema(), fragment, state.reachableArguments, '@relay(unmask: true)');
+  var joinedArgumentDefinitions = joinArgumentDefinitions( // $FlowFixMe[incompatible-use]
+  this.getContext().getSchema(), fragment, state.reachableArguments, '@relay(unmask: true)');
   return (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, result), {}, {
     argumentDefinitions: joinedArgumentDefinitions
   });
@@ -58,7 +60,8 @@ function visitFragmentSpread(fragmentSpread, state) {
     return fragmentSpread;
   }
 
-  !(fragmentSpread.args.length === 0) ? process.env.NODE_ENV !== "production" ? invariant(false, 'MaskTransform: Cannot unmask fragment spread `%s` with ' + 'arguments. Use the `ApplyFragmentArgumentTransform` before flattening', fragmentSpread.name) : invariant(false) : void 0;
+  !(fragmentSpread.args.length === 0) ? process.env.NODE_ENV !== "production" ? invariant(false, 'MaskTransform: Cannot unmask fragment spread `%s` with ' + 'arguments. Use the `ApplyFragmentArgumentTransform` before flattening', fragmentSpread.name) : invariant(false) : void 0; // $FlowFixMe[incompatible-use]
+
   var context = this.getContext();
   var fragment = context.getFragment(fragmentSpread.name);
   var result = {
@@ -94,7 +97,8 @@ function visitFragmentSpread(fragmentSpread, state) {
     for (_iterator.s(); !(_step = _iterator.n()).done;) {
       var argDef = _step.value;
       state.reachableArguments.push(argDef);
-    }
+    } // $FlowFixMe[incompatible-use]
+
   } catch (err) {
     _iterator.e(err);
   } finally {
