@@ -3,7 +3,7 @@ import styles from '@patternfly/react-styles/css/components/Select/select';
 import formStyles from '@patternfly/react-styles/css/components/Form/form';
 import { css } from '@patternfly/react-styles';
 import { SelectOptionObject, SelectOption } from './SelectOption';
-import { SelectConsumer, SelectVariant, SelectContextInterface } from './selectConstants';
+import { SelectConsumer, SelectPosition, SelectVariant, SelectContextInterface } from './selectConstants';
 import { PickOptional } from '../../helpers/typeUtils';
 
 import { SelectGroup } from './SelectGroup';
@@ -28,6 +28,8 @@ export interface SelectMenuProps extends Omit<React.HTMLProps<HTMLElement>, 'che
   openedOnEnter?: boolean;
   /** Flag to specify the  maximum height of the menu, as a string percentage or number of pixels */
   maxHeight?: string | number;
+  /** Indicates where menu will be alligned horizontally */
+  position?: SelectPosition | 'right' | 'left';
   /** Inner prop passed from parent */
   noResultsFoundText?: string;
   /** Inner prop passed from parent */
@@ -43,6 +45,8 @@ export interface SelectMenuProps extends Omit<React.HTMLProps<HTMLElement>, 'che
   footer?: React.ReactNode;
   /** The menu footer element */
   footerRef?: React.RefObject<HTMLDivElement>;
+  /** @hide callback to check if option is the last one in the menu when there is a footer  */
+  isLastOptionBeforeFooter?: (index: number) => void;
 }
 
 class SelectMenuWithRef extends React.Component<SelectMenuProps> {
@@ -54,10 +58,12 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
     openedOnEnter: false,
     selected: '',
     maxHeight: '',
+    position: SelectPosition.left,
     sendRef: () => {},
     keyHandler: () => {},
     isCustomContent: false,
-    hasInlineFilter: false
+    hasInlineFilter: false,
+    isLastOptionBeforeFooter: () => {}
   };
 
   extendChildren(randomId: string) {
@@ -125,7 +131,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
   }
 
   extendCheckboxChildren(children: React.ReactElement[]) {
-    const { isGrouped, checked, sendRef, keyHandler, hasInlineFilter } = this.props;
+    const { isGrouped, checked, sendRef, keyHandler, hasInlineFilter, isLastOptionBeforeFooter } = this.props;
     let index = hasInlineFilter ? 1 : 0;
     if (isGrouped) {
       return React.Children.map(children, (group: React.ReactElement) => {
@@ -146,7 +152,8 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
                       isChecked: this.checkForValue(option.props.value, checked),
                       sendRef,
                       keyHandler,
-                      index: index++
+                      index: index++,
+                      isLastOptionBeforeFooter
                     })
               )}
             </fieldset>
@@ -161,7 +168,8 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
             isChecked: this.checkForValue(child.props.value, checked),
             sendRef,
             keyHandler,
-            index: index++
+            index: index++,
+            isLastOptionBeforeFooter
           })
     );
   }
@@ -177,6 +185,7 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
       selected,
       checked,
       isGrouped,
+      position,
       sendRef,
       keyHandler,
       maxHeight,
@@ -188,13 +197,18 @@ class SelectMenuWithRef extends React.Component<SelectMenuProps> {
       innerRef,
       footer,
       footerRef,
+      isLastOptionBeforeFooter,
       ...props
     } = this.props;
     /* eslint-enable @typescript-eslint/no-unused-vars */
     let Component = 'div';
     const variantProps = {
       ref: innerRef,
-      className: css(!footer ? styles.selectMenu : 'pf-c-select__menu-list', className),
+      className: css(
+        !footer ? styles.selectMenu : 'pf-c-select__menu-list',
+        position === SelectPosition.right && styles.modifiers.alignRight,
+        className
+      ),
       ...(maxHeight && { style: { maxHeight, overflow: 'auto' } })
     } as React.HTMLAttributes<HTMLElement>;
     const extendedChildren = () =>
