@@ -472,3 +472,127 @@ invalidErrorCodes.forEach((invalidCode) => {
     })
   })
 })
+
+test('status code should be set to 500 and return an error json payload if route handler throws any non Error object expression', async t => {
+  t.plan(2)
+  const fastify = Fastify()
+
+  fastify.get('/', () => {
+    /* eslint-disable-next-line */
+    throw { foo: 'bar' }
+  })
+
+  // ----
+  const reply = await fastify.inject({ method: 'GET', url: '/' })
+  t.equal(reply.statusCode, 500)
+  t.equal(JSON.parse(reply.body).foo, 'bar')
+})
+
+test('should preserve the status code set by the user if an expression is thrown in a sync route', async t => {
+  t.plan(2)
+  const fastify = Fastify()
+
+  fastify.get('/', (_, rep) => {
+    rep.status(501)
+
+    /* eslint-disable-next-line */
+    throw { foo: 'bar' }
+  })
+
+  // ----
+  const reply = await fastify.inject({ method: 'GET', url: '/' })
+  t.equal(reply.statusCode, 501)
+  t.equal(JSON.parse(reply.body).foo, 'bar')
+})
+
+test('should trigger error handlers if a sync route throws any non-error object', async t => {
+  t.plan(3)
+
+  const fastify = Fastify()
+
+  fastify.get('/', () => {
+    /* eslint-disable-next-line */
+    throw { foo: 'bar' }
+  })
+
+  fastify.setErrorHandler(async (error) => {
+    t.ok(error)
+    return error
+  })
+
+  // ----
+  const reply = await fastify.inject({ method: 'GET', url: '/' })
+  t.equal(reply.statusCode, 500)
+  t.equal(JSON.parse(reply.body).foo, 'bar')
+})
+
+test('setting content-type on reply object should not hang the server case 1', t => {
+  t.plan(2)
+  const fastify = Fastify()
+
+  fastify.get('/', (req, reply) => {
+    reply
+      .code(200)
+      .headers({ 'content-type': 'text/plain; charset=utf-32' })
+      .send(JSON.stringify({ bar: 'foo', baz: 'foobar' }))
+  })
+
+  fastify.inject({
+    url: '/',
+    method: 'GET'
+  }, (err, res) => {
+    t.error(err)
+    t.equal(res.statusCode, 200)
+  })
+})
+
+test('setting content-type on reply object should not hang the server case 2', async t => {
+  t.plan(1)
+  const fastify = Fastify()
+
+  fastify.get('/', (req, reply) => {
+    reply
+      .code(200)
+      .headers({ 'content-type': 'text/plain; charset=utf-8' })
+      .send({ bar: 'foo', baz: 'foobar' })
+  })
+
+  try {
+    await fastify.listen(0)
+    const res = await fastify.inject({
+      url: '/',
+      method: 'GET'
+    })
+    t.same({
+      error: 'Internal Server Error',
+      message: 'Attempted to send payload of invalid type \'object\'. Expected a string or Buffer.',
+      statusCode: 500,
+      code: 'FST_ERR_REP_INVALID_PAYLOAD_TYPE'
+    },
+    res.json())
+  } catch (error) {
+    t.error(error)
+  } finally {
+    await fastify.close()
+  }
+})
+
+test('setting content-type on reply object should not hang the server case 3', t => {
+  t.plan(2)
+  const fastify = Fastify()
+
+  fastify.get('/', (req, reply) => {
+    reply
+      .code(200)
+      .headers({ 'content-type': 'application/json' })
+      .send({ bar: 'foo', baz: 'foobar' })
+  })
+
+  fastify.inject({
+    url: '/',
+    method: 'GET'
+  }, (err, res) => {
+    t.error(err)
+    t.equal(res.statusCode, 200)
+  })
+})
