@@ -1190,3 +1190,81 @@ test('HEAD routes properly auto created for GET routes when prefixTrailingSlash:
   t.equal(trailingSlashReply.statusCode, 200)
   t.equal(noneTrailingReply.statusCode, 200)
 })
+
+test('Request and Reply share the route config', async t => {
+  t.plan(3)
+
+  const fastify = Fastify()
+
+  const config = {
+    this: 'is a string',
+    thisIs: function aFunction () {}
+  }
+
+  fastify.route({
+    method: 'GET',
+    url: '/',
+    config,
+    handler: (req, reply) => {
+      t.same(req.context, reply.context)
+      t.same(req.context.config, reply.context.config)
+      t.match(req.context.config, config, 'there are url and method additional properties')
+
+      reply.send({ hello: 'world' })
+    }
+  })
+
+  await fastify.inject('/')
+})
+
+test('Will not try to re-createprefixed HEAD route if it already exists and exposeHeadRoutes is true', async (t) => {
+  t.plan(1)
+
+  const fastify = Fastify({ exposeHeadRoutes: true })
+
+  fastify.register((scope, opts, next) => {
+    scope.route({
+      method: 'HEAD',
+      path: '/route',
+      handler: (req, reply) => {
+        reply.header('content-type', 'text/plain')
+        reply.send('custom HEAD response')
+      }
+    })
+    scope.route({
+      method: 'GET',
+      path: '/route',
+      handler: (req, reply) => {
+        reply.send({ ok: true })
+      }
+    })
+
+    next()
+  }, { prefix: '/prefix' })
+
+  await fastify.ready()
+
+  t.ok(true)
+})
+
+test('Correct error message is produced if "path" option is used', t => {
+  t.plan(2)
+
+  const fastify = Fastify()
+
+  t.throws(() => {
+    fastify.route({
+      method: 'GET',
+      path: '/test'
+    })
+  }, new Error('Missing handler function for GET:/test route.'))
+
+  t.throws(() => {
+    fastify.route({
+      method: 'POST',
+      url: '/test',
+      handler: function () {},
+      errorHandler: ''
+    })
+  }, new Error('Error Handler for POST:/test route, if defined, must be a function'))
+})
