@@ -1,5 +1,11 @@
-import fastify, { FastifyBodyParser, FastifyError, FastifyInstance, ValidationResult } from '../../fastify'
-import { expectAssignable, expectError, expectType } from 'tsd'
+import fastify, {
+  FastifyBodyParser,
+  FastifyError,
+  FastifyInstance,
+  RawReplyDefaultExpression,
+  RawRequestDefaultExpression
+} from '../../fastify'
+import { expectAssignable, expectError, expectNotAssignable, expectType } from 'tsd'
 import { FastifyRequest } from '../../types/request'
 import { FastifyReply } from '../../types/reply'
 import { HookHandlerDoneFunction } from '../../types/hooks'
@@ -36,9 +42,15 @@ expectAssignable<FastifyInstance>(
 function fastifyErrorHandler (this: FastifyInstance, error: FastifyError) {}
 server.setErrorHandler(fastifyErrorHandler)
 
+async function asyncFastifyErrorHandler (this: FastifyInstance, error: FastifyError) {}
+server.setErrorHandler(asyncFastifyErrorHandler)
+
 function nodeJSErrorHandler (error: NodeJS.ErrnoException) {}
 server.setErrorHandler(nodeJSErrorHandler)
 
+function asyncNodeJSErrorHandler (error: NodeJS.ErrnoException) {}
+server.setErrorHandler(asyncNodeJSErrorHandler)
+
 function notFoundHandler (request: FastifyRequest, reply: FastifyReply) {}
 function notFoundpreHandlerHandler (request: FastifyRequest, reply: FastifyReply, done: HookHandlerDoneFunction) { done() }
 async function notFoundpreHandlerAsyncHandler (request: FastifyRequest, reply: FastifyReply) {}
@@ -94,6 +106,8 @@ expectAssignable<void>(server.listen({ port: 3000 }, () => {}))
 expectAssignable<void>(server.listen({ port: 3000, host: '0.0.0.0' }, () => {}))
 expectAssignable<void>(server.listen({ port: 3000, host: '0.0.0.0', backlog: 42 }, () => {}))
 
+expectAssignable<void>(server.routing({} as RawRequestDefaultExpression, {} as RawReplyDefaultExpression))
+
 expectType<FastifyInstance>(fastify().get('/', {
   handler: () => {},
   errorHandler: (error, request, reply) => {
@@ -124,3 +138,35 @@ expectType<InitialConfig>(fastify().initialConfig)
 expectType<FastifyBodyParser<string>>(server.defaultTextParser)
 
 expectType<FastifyBodyParser<string>>(server.getDefaultJsonParser('ignore', 'error'))
+
+expectType<string>(server.printRoutes({ includeHooks: true, commonPrefix: false, includeMeta: true }))
+
+expectType<string>(server.printRoutes({ includeMeta: ['key1', Symbol('key2')] }))
+
+expectType<string>(server.printRoutes())
+
+server.decorate<(x: string) => void>('test', function (x: string): void {
+  expectType<FastifyInstance>(this)
+})
+server.decorate('test', function (x: string): void {
+  expectType<FastifyInstance>(this)
+})
+
+server.decorateRequest<(x: string, y: number) => void>('test', function (x: string, y: number): void {
+  expectType<FastifyRequest>(this)
+})
+server.decorateRequest('test', function (x: string, y: number): void {
+  expectType<FastifyRequest>(this)
+})
+
+server.decorateReply<(x: string) => void>('test', function (x: string): void {
+  expectType<FastifyReply>(this)
+})
+server.decorateReply('test', function (x: string): void {
+  expectType<FastifyReply>(this)
+})
+
+expectError(server.decorate<string>('test', true))
+expectError(server.decorate<(myNumber: number) => number>('test', function (myNumber: number): string {
+  return ''
+}))
